@@ -91,7 +91,11 @@ def empty_bucket(bucket):
 
 
 def delete_blob(blob):
-    errors = (exceptions.Conflict, exceptions.TooManyRequests)
+    errors = (
+        exceptions.Conflict,
+        exceptions.TooManyRequests,
+        exceptions.ServiceUnavailable,
+    )
     retry = RetryErrors(errors)
     try:
         retry(blob.delete)(timeout=120)  # seconds
@@ -105,14 +109,22 @@ def delete_blob(blob):
 
 
 def delete_bucket(bucket):
-    errors = (exceptions.Conflict, exceptions.TooManyRequests)
+    errors = (
+        exceptions.Conflict,
+        exceptions.TooManyRequests,
+        exceptions.ServiceUnavailable,
+    )
     retry = RetryErrors(errors, max_tries=15)
     retry(empty_bucket)(bucket)
     retry(bucket.delete)(force=True)
 
 
-def await_config_changes_propagate(sec=3):
+def await_config_changes_propagate(sec=12):
     # Changes to the bucket will be readable immediately after writing,
     # but configuration changes may take time to propagate.
     # See https://cloud.google.com/storage/docs/json_api/v1/buckets/patch
+    #
+    # The default was changed from 3 to 12 in May 2023 due to changes in bucket
+    # metadata handling. Note that the documentation recommends waiting "30
+    # seconds".
     time.sleep(sec)
