@@ -1117,3 +1117,32 @@ def test_blob_update_storage_class_large_file(
     blob.update_storage_class(constants.COLDLINE_STORAGE_CLASS)
     blob.reload()
     assert blob.storage_class == constants.COLDLINE_STORAGE_CLASS
+
+
+def test_object_retention_lock(storage_client, buckets_to_delete, blobs_to_delete):
+    # Test bucket created with object retention enabled
+    new_bucket_name = _helpers.unique_name("object-retention")
+    created_bucket = _helpers.retry_429_503(storage_client.create_bucket)(
+        new_bucket_name, enable_object_retention=True
+    )
+    buckets_to_delete.append(created_bucket)
+    assert created_bucket.object_retention_mode == "Enabled"
+
+    # Test create object with object retention enabled
+    payload = b"Hello World"
+    mode = "Unlocked"
+    current_time = datetime.datetime.utcnow()
+    expiration_time = current_time + datetime.timedelta(seconds=10)
+    blob = created_bucket.blob("object-retention-lock")
+    blob.retention.mode = mode
+    blob.retention.retain_until_time = expiration_time
+    blob.upload_from_string(payload)
+    blobs_to_delete.append(blob)
+    blob.reload()
+    assert blob.retention.mode == mode
+
+    # Test patch object to disable object retention
+    blob.retention.mode = None
+    blob.retention.retain_until_time = None
+    blob.patch(override_unlocked_retention=True)
+    assert blob.retention.mode is None
